@@ -1,6 +1,7 @@
 from enum import Enum
 
-from strictdoc.backend.dsl.models import Document, Requirement, ReqComment, Section, CompositeRequirement, FreeText
+from strictdoc.backend.dsl.models.requirement import Requirement
+from strictdoc.backend.dsl.models.section import FreeText, Section
 from strictdoc.core.document_iterator import DocumentCachingIterator
 
 
@@ -14,19 +15,22 @@ class RSTWriter:
     def __init__(self):
         pass
 
-    def write(self, document):
+    def write(self, document, single_document):
         document_iterator = DocumentCachingIterator(document)
         output = ""
 
-        # output += self._print_rst_header(document.name, 0)
+        if not single_document:
+            output += self._print_rst_header(document.name, 0)
+
+        for free_text in document.free_texts:
+            output += self._print_free_text(free_text)
 
         for content_node in document_iterator.all_content():
-            if isinstance(content_node, FreeText):
-                output += self._print_free_text(content_node)
-                continue
-
             if isinstance(content_node, Section):
                 output += self._print_rst_header(content_node.title, content_node.ng_level)
+                for free_text in content_node.free_texts:
+                    output += self._print_free_text(free_text)
+
             elif isinstance(content_node, Requirement):
                 output += self._print_rst_header(content_node.title, content_node.ng_level)
                 output += self._print_requirement_fields(content_node)
